@@ -3,7 +3,7 @@
 	 *
 	 * Copyright (C) by Hugo Leisink <hugo@leisink.net>
 	 * This file is part of the Banshee PHP framework
-	 * http://www.hiawatha-webserver.org/banshee
+	 * http://www.banshee-php.org/
 	 *
 	 * Don't change this file, unless you know what you are doing.
 	 */
@@ -14,12 +14,13 @@
 		protected $db_escape_string = null;
 		protected $db_query = null;
 		protected $db_fetch = null;
+		protected $db_free_result = null;
 		protected $db_insert_id = null;
 		protected $db_affected_rows = null;
 		protected $db_error = null;
 		protected $db_errno = null;
-		protected $insert_id_history = array();
 		protected $id_delim = null;
+		private $insert_id_history = array();
 
 		/* Desctructor
 		 *
@@ -30,6 +31,7 @@
 		public function __destruct() {
 			if ($this->link !== null) {
 				call_user_func($this->db_close, $this->link);
+				$this->link = null;
 			}
 		}
 
@@ -39,17 +41,27 @@
 		 * OUTPUT: mixed value
 		 * ERROR:  null
 		 */
-		public function __get($var) {
-			if ($var == "connected") {
-				return $this->link !== null;
-			} else if ($var == "last_insert_id") {
-				return $this->last_insert_id(0);
-			} else if (($var == "affected_rows") && ($this->db_affected_rows != null)) {
-				return call_user_func($this->db_affected_rows, $this->link);
-			} else if (($var == "error") && ($this->db_error != null)) {
-				return call_user_func($this->db_error, $this->link);
-			} else if (($var == "errno") && ($this->db_errno != null)) {
-				return call_user_func($this->db_errno, $this->link);
+		public function __get($key) {
+			switch ($key) {
+				case "connected":
+					return $this->link !== null;
+				case "last_insert_id":
+					return $this->last_insert_id(0);
+				case "affected_rows":
+					if ($this->db_affected_rows !== null) {
+						return call_user_func($this->db_affected_rows, $this->link);
+					}
+					break;
+				case "error":
+					if ($this->db_error !== null) {
+						return call_user_func($this->db_error, $this->link);
+					}
+					break;
+				case "errno":
+					if ($this->db_errno !== null) {
+						return call_user_func($this->db_errno, $this->link);
+					}
+					break;
 			}
 
 			return null;
@@ -147,12 +159,15 @@
 			$args = func_get_args();
 			$format = array_shift($args);
 			$values = $this->flatten_array($args);
+			unset($args);
 
 			/* Security checks
 			 */
-			if ((strpos($format, "'") !== false) || (strpos($format, "`") !== false)) {
-				print $format."\nQuery not accepted.\n";
-				return false;
+			foreach (array("'", "`", "\"") as $char) {
+				if (strpos($format, $char) !== false) {
+					print $format."\nQuery not accepted.\n";
+					return false;
+				}
 			}
 
 			$format = str_replace("%s", "'%s'", $format);
@@ -160,8 +175,8 @@
 
 			/* Escape arguments
 			 */
-			foreach ($values as $key => $value) {
-				$values[$key] = call_user_func($this->db_escape_string, $value);
+			foreach ($values as &$value) {
+				$value = call_user_func($this->db_escape_string, $value);
 			}
 
 			/* Apply arguments to format
@@ -177,7 +192,7 @@
 		 */
 		public function query() {
 			if ($this->connected == false) {
-				print "Not connected to database!\n";
+				print "Not connected to the database!\n";
 				return false;
 			}
 
@@ -189,7 +204,7 @@
 			$result = call_user_func($this->db_query, $query, $this->link);
 			if ($result === false) {
 				print "SQL query: ".$query."\n";
-				print "Error message: ".call_user_func($this->db_error, $this->link)."\n";
+				print "Error message: ".$this->error."\n";
 			} else if (($insert_id = $this->last_insert_id()) != 0) {
 				array_unshift($this->insert_id_history, $insert_id);
 			}
@@ -204,7 +219,27 @@
 		 * ERROR:  false
 		 */
 		public function fetch($resource) {
-			return call_user_func($this->db_fetch, $resource);
+			if (in_array($resource, array(null, false, true), true)) {
+				$result = false;
+			} else if (($result = call_user_func($this->db_fetch, $resource)) === null) {
+				$result = false;
+			}
+
+			return $result;
+		}
+
+		/* Free query result memory
+		 *
+		 * INPUT:  mixed resource identifier
+		 * OUTPUT: boolean success
+		 * ERROR:  -
+		 */
+		public function free_result($resource) {
+			if ($this->db_free_result === null) {
+				return true;
+			}
+
+			return call_user_func($this->db_free_result, $resource);
 		}
 
 		/* Execute a SQL query and return the result
@@ -216,31 +251,32 @@
 		public function execute() {
 			$args = func_get_args();
 
-			if (($resource = call_user_func_array(array($this, "query"), $args)) != false) {
-				$words = explode(" ", ltrim($args[0]), 2);
-				$statement = strtolower($words[0]);
-
-				if (($statement == "select") || ($statement == "show")) {
-					$result = array();
-					while (($data = $this->fetch($resource)) != false) {
-						array_push($result, $data);
-					}
-
-					return $result;
-				} else if ($this->db_affected_row != null) {
-					return call_user_func($this->db_affected_rows, $this->link);
-				} else {
-					return true;
-				}
+			$resource = call_user_func_array(array($this, "query"), $args);
+			if (is_bool($resource)) {
+				return $resource;
 			}
 
-			return false;
+			$statement = strtolower(array_shift(explode(" ", ltrim($args[0]), 2)));
+
+			if (in_array($statement, array("select", "show", "describe", "explain"))) {
+				$result = array();
+				while (($data = $this->fetch($resource)) !== false) {
+					array_push($result, $data);
+				}
+				$this->free_result($resource);
+
+				return $result;
+			} else if ($this->db_affected_rows !== null) {
+				return call_user_func($this->db_affected_rows, $this->link);
+			}
+
+			return true;
 		}
 
 		/* Execute queries via transaction
 		 *
 		 * INPUT:  array( array( string query[, mixed query parameter, ...] )[, ...] )
-		 * OUTPUT: -
+		 * OUTPUT: boolean transaction succesful
 		 * ERROR:  -
 		 */
 		public function transaction($queries) {
@@ -272,7 +308,7 @@
 				$query_nr++;
 			}
 
-			return $this->query("commit") != false;
+			return $this->query("commit") !== false;
 		}
 
 		/* Retrieve an entry from a table
@@ -312,7 +348,7 @@
 				if ($data[$key] === null) {
 					array_push($format, "null");
 				} else {
-					array_push($format, is_integer($data[$key]) ? "%d" : "%s");
+					array_push($format, is_int($data[$key]) ? "%d" : "%s");
 					array_push($values, $data[$key]);
 				}
 			}
@@ -352,7 +388,7 @@
 					array_push($format, "%S=null");
 					array_push($values, $key);
 				} else {
-					array_push($format, "%S=".(is_integer($data[$key]) ? "%d" : "%s"));
+					array_push($format, "%S=".(is_int($data[$key]) ? "%d" : "%s"));
 					array_push($values, $key);
 					array_push($values, $data[$key]);
 				}
