@@ -3,7 +3,7 @@
 	 *
 	 * Copyright (C) by Hugo Leisink <hugo@leisink.net>
 	 * This file is part of the Banshee PHP framework
-	 * http://www.hiawatha-webserver.org/banshee
+	 * http://www.banshee-php.org/
 	 */
 
 	class output extends XML {
@@ -12,6 +12,8 @@
 		private $description = HEAD_DESCRIPTION;
 		private $keywords = HEAD_KEYWORDS;
 		private $messages = array();
+		private $javascripts = array();
+		private $onload_javascript = null;
 		private $alternates = array();
 		private $title = null;
 		private $css_links = array();
@@ -37,7 +39,7 @@
 			 */
 			if (substr($this->page->url, 0, 6) == "/admin") {
 				$this->layout = "layout_cms";
-			} else if ($this->page->module == "logout") {
+			} else if (in_array($this->page->module, array(LOGIN_PAGE, LOGOUT_PAGE, "password"))) {
 				if ($_SESSION["previous_layout"] == "layout_cms") {
 					$this->layout = "layout_cms";
 				}
@@ -98,8 +100,8 @@
 		 * OUTPUT: -
 		 * ERROR:  -
 		 */
-		public function exception_handler($e) {
-			print "Caught exception '".$e->getmessage()."'<br />\n";
+		public function exception_handler($error) {
+			print "Caught exception '".$error->getmessage()."'<br />\n";
 		}
 
 		/* Error handler
@@ -122,12 +124,47 @@
 			if (file_exists("css/".$css) == false) {
 				return false;
 			}
+			$css = "/css/".$css;
 
-			array_push($this->css_links, $css);
+			if (in_array($css, $this->css_links) == false) {
+				array_push($this->css_links, $css);
+			}
 
 			return true;
 		}
 
+		/* Add javascript link
+		 *
+		 * INPUT:  string link
+		 * OUTPUT: -
+		 * ERROR:  -
+		 */
+		public function add_javascript($script) {
+			if ((substr($script, 0, 7) != "http://") && (substr($script, 0, 8) != "https://")) {
+				if (file_exists("js/".$script) == false) {
+					return false;
+				}
+
+				$script = "/js/".$script;
+			}
+
+			if (in_array($script, $this->javascripts) == false) {
+				array_push($this->javascripts, $script);
+			}
+
+			return true;
+		}
+
+		/* Set onload function of body tag
+		 *
+		 * INPUT:  string javascript function
+		 * OUTPUT: -
+		 * ERROR:  -
+		 */
+		public function onload_javascript($function) {
+			$this->onload_javascript = $function;
+		}
+
 		/* Add alternate link
 		 *
 		 * INPUT:  string title, string type, string url
@@ -203,6 +240,18 @@
 				$this->close_tag();
 				$this->add_tag("inline_css", $this->inline_css);
 
+				/* Javascripts
+				 */
+				$params = array();
+				if ($this->onload_javascript !== null) {
+					$params["onload"] = $this->onload_javascript;
+				}
+				$this->open_tag("javascripts", $params);
+				foreach ($this->javascripts as $javascript) {
+					$this->add_tag("javascript", $javascript);
+				}
+				$this->close_tag();
+
 				/* Alternates
 				 */
 				$this->open_tag("alternates");
@@ -225,6 +274,16 @@
 			parent::close_tag();
 		}
 
+		/* Mask transform function
+		 *
+		 * INPUT:  -
+		 * OUTPUT: -
+		 * ERROR:  false
+		 */
+		public function transform() {
+			return false;
+		}
+
 		/* Generate output via XSLT
 		 *
 		 * INPUT:  string output type, string XSLT file
@@ -232,9 +291,13 @@
 		 * ERROR:  -
 		 */
 		public function generate($output, $view = null) {
-			$errors = ob_get_contents();
+			$errors = trim(ob_get_contents());
 			ob_end_clean();
 
+			if (($output == null) && $this->page->ajax_request) {
+				$output = "xml";
+			}
+
 			switch ($output) {
 				case "xml":
 					header("Content-Type: text/xml");
@@ -250,7 +313,7 @@
 				case null:
 					$this->set_xslt_parameter("layout", "site");
 
-					if (($html = $this->transform($view)) === false) {
+					if (($html = parent::transform($view)) === false) {
 						print "XSL Transformation error";
 						return;
 					}
@@ -299,6 +362,7 @@
 							if ($encoding == "gzip") {
 								header("Content-Encoding: gzip");
 								$html = gzencode($html, 6);
+								break;
 							}
 						}
 					}
