@@ -3,7 +3,7 @@
 	 *
 	 * Copyright (C) by Hugo Leisink <hugo@leisink.net>
 	 * This file is part of the Banshee PHP framework
-	 * http://www.hiawatha-webserver.org/banshee
+	 * http://www.banshee-php.org/
 	 *
 	 * Don't change this file, unless you know what you are doing.
 	 */
@@ -26,17 +26,20 @@
 		 * OUTPUT: -
 		 * ERROR:  -
 		 */
-		public function __construct($db, $user, $ajax_request = false) {
+		public function __construct($db, $user) {
 			$this->db = $db;
 			$this->user = $user;
-			$this->ajax_request = $ajax_request;
+			$this->ajax_request = $_ENV["HTTP_X_REQUEST_TYPE"] == "AJAX";
+			if (is_true(DEBUG) && ($this->ajax_request == false)) {
+				$this->ajax_request = $_GET["banshee_ajax"] !== null;
+			}
 
 			/* Prevent Cross-Site Request Forgery
 			 */
-			if ($_SERVER["REQUEST_METHOD"] == "POST") {
-				list($protocol,, $referer_host) = explode("/", $_SERVER["HTTP_REFERER"]);
-				if (($protocol == "http:") && ($_SERVER["HTTP_HOST"] != $referer_host)) {
-					$user->logout();
+			if (($_SERVER["REQUEST_METHOD"] == "POST") && isset($_SERVER["HTTP_REFERER"])) {
+				list($protocol,, $referer_host) = explode("/", $_SERVER["HTTP_REFERER"], 4);
+				if ((($protocol == "http:") || ($protocol == "https:")) && ($_SERVER["HTTP_HOST"] != $referer_host)) {
+					$this->user->logout();
 					$_SERVER["REQUEST_METHOD"] = "GET";
 					$_GET = array();
 					$_POST = array();
@@ -50,14 +53,10 @@
 				$this->http_code = 500;
 			} else {
 				list($this->url) = explode("?", $_SERVER["REQUEST_URI"], 2);
-				if (($this->url == "/index.php") || ($this->url == "/ajax.php")) {
-					$page = isset($_GET["page"]) ? $_GET["page"] : START_PAGE;
-					$this->pathinfo[0] = $page;
-				} else {
-					$path = trim($this->url, "/");
-					$page = valid_input($path, VALIDATE_URL, VALIDATE_NONEMPTY) ? $path : START_PAGE;
-					$this->pathinfo = secure_input(explode("/", $page));
-				}
+				$path = trim($this->url, "/");
+
+				$page = valid_input($path, VALIDATE_URL, VALIDATE_NONEMPTY) ? $path : START_PAGE;
+				$this->pathinfo = secure_input(explode("/", $page));
 			}
 
 			$this->select_module($page);
@@ -70,6 +69,7 @@
 		 * ERROR:  -
 		 */
 		public function __destruct() {
+			$_SESSION["previous_page"] = $this->page;
 			$_SESSION["last_visit"] = time();
 		}
 		
@@ -79,8 +79,8 @@
 		 * OUTPUT: mixed value
 		 * ERROR:  null
 		 */
-		public function __get($var) {
-			switch ($var) {
+		public function __get($key) {
+			switch ($key) {
 				case "module": return $this->module;
 				case "url": return $this->url;
 				case "page": return $this->page !== null ? $this->page : $this->module;
@@ -91,7 +91,6 @@
 				case "ajax_request": return $this->ajax_request;
 				case "is_public": return $this->is_public;
 				case "is_private": return $this->is_public == false;
-				case "logged_in": return $this->logged_in;
 			}
 
 			return null;
@@ -101,7 +100,7 @@
 		 *
 		 * INPUT:  string URL, string page configuration file
 		 * OUTPUT: string module identifier
-		 * ERROR:  -
+		 * ERROR:  null
 		 */
 		private function page_on_disk($url, $page_file) {
 			$module = null;
@@ -141,9 +140,9 @@
 
 		/* Page available in database
 		 *
-		 * INPUT:  string URL, int page type
+		 * INPUT:  string URL, int private page
 		 * OUTPUT: string module identifier
-		 * ERROR:  -
+		 * ERROR:  null
 		 */
 		private function page_in_database($url, $private) {
 			$query = "select id,visible from pages where url=%s and private=%d limit 1";
@@ -169,7 +168,7 @@
 		 * ERROR:  -
 		 */
 		public function select_module($page) {
-			if (($this->module !== null) && ($this->module !== "login")) {
+			if (($this->module !== null) && ($this->module !== LOGIN_PAGE)) {
 				return;
 			}
 
@@ -189,14 +188,6 @@
 				}
 			}
 
-			/* AJAX page
-			 */
-			if ($this->ajax_request) {
-				if (($this->module = $this->page_on_disk($page, "ajax_pages")) !== null) {
-					return;
-				}
-			}
-
 			/* Public page
 			 */
 			if (($this->module = $this->page_on_disk($page, "public_pages")) !== null) {
@@ -207,7 +198,7 @@
 
 			/* Change profile before access to private pages
 			 */
-			if ($this->user->logged_in && ($page != "logout")) {
+			if ($this->user->logged_in && ($page != LOGOUT_PAGE)) {
 				if ($this->user->status == USER_STATUS_CHANGEPWD) {
 					$page = "profile";
 					$this->type = "";
@@ -229,7 +220,7 @@
 			} else if ($this->user->logged_in == false) {
 				/* User not logged in.
 				 */
-				$this->module = "login";
+				$this->module = LOGIN_PAGE;
 				$this->type = "";
 			} else if ($this->user->access_allowed($this->__get("page").$this->type) == false) {
 				/* Access denied because not with right role.
