@@ -151,17 +151,15 @@
 
 		/* Public pages on disk
 		 */
-		$public = config_file("public_pages");
+		$public = page_to_module(config_file("public_pages"));
 		foreach ($public as $page) {
-			$page = str_replace("*/", "", $page);
 			$access_rights[$page] = 1;
 		}
 
 		/* Private pages on disk
 		 */
-		$private = config_file("private_pages");
+		$private = page_to_module(config_file("private_pages"));
 		foreach ($private as $page) {
-			$page = str_replace("*/", "", $page);
 			$access_rights[$page] = $_user->is_admin ? YES : NO;
 		}
 		$access_rights["logout"] = $_user->logged_in ? YES : NO;
