@@ -8,8 +8,8 @@
 
 	/* For internal usage. Only change if you know what you're doing!
 	 */
-	define("BANSHEE_VERSION", "1.3");
-	define("MONITOR_VERSION", "0.2");
+	define("BANSHEE_VERSION", "2.1");
+	define("MONITOR_VERSION", "0.3");
 	define("ADMIN_ROLE_ID", 1);
 	define("YES", 1);
 	define("NO", 0);
@@ -19,6 +19,8 @@
 	define("SESSION_NAME", "WebsiteSessionID");
 	define("PAGE_MODULE", "includes/page");
 	define("DAY", 86400);
+	define("LOGIN_PAGE", "login");
+	define("LOGOUT_PAGE", "logout");
 
 	/* Hiawatha Monitor settings
 	 */
@@ -39,10 +41,6 @@
 	define("VALIDATE_NONEMPTY",     0);
 
 	$allowed_uploads = array("jpg", "jpeg", "gif", "png", "pdf", "doc", "xls", "zip", "txt");
-	$months_of_year = array("january", "february", "march", "april", "may", "june",
-		"july", "august", "september", "october", "november", "december");
-	$days_of_week = array("monday", "tuesday", "wednesday", "thursday", "friday",
-		"saturday", "sunday");
 
 	/* Class for settings in database
 	 */
@@ -122,16 +120,7 @@
 	 * ERROR:  -
 	 */
 	function __autoload($class_name) {
-		$rename = array(
-			"HTTPS"       => "HTTP",
-			"HTTP_proxy"  => "HTTP",
-			"HTTPS_proxy" => "HTTP",
-			"POP3S"       => "POP3");
-		if (isset($rename[$class_name])) {
-			$class_name = $rename[$class_name];
-		}
-
-		$locations = array("libraries", "libraries/database");
+		$locations = array("libraries", "libraries/database", "libraries/oo");
 		foreach ($locations as $location) {
 			if (file_exists($file = "../".$location."/".strtolower($class_name).".php")) {
 				include_once($file);
