@@ -3,7 +3,7 @@
 	 *
 	 * Copyright (C) by Hugo Leisink <hugo@leisink.net>
 	 * This file is part of the Banshee PHP framework
-	 * http://www.hiawatha-webserver.org/banshee
+	 * http://www.banshee-php.org/
 	 *
 	 * Don't change this file, unless you know what you are doing.
 	 */
@@ -32,7 +32,7 @@
 
 			if (isset($_SESSION["user_id"])) {
 				if (time() - $_SESSION["last_private_visit"] >= SESSION_TIMEOUT) {
-					unset($_SESSION["user_id"]);
+					$this->logout();
 				} else if (($_SESSION["binded_ip"] === NO) || ($_SESSION["binded_ip"] === $this->client_ip)) {
 					$this->load_user_record($_SESSION["user_id"]);
 				}
@@ -45,17 +45,16 @@
 		 * OUTPUT: mixed value
 		 * ERROR:  null
 		 */
-		public function __get($var) {
-			if ($var == "logged_in") {
-				return $this->logged_in;
-			} else if ($var == "id") {
-				return $this->id;
-			} else if ($var == "is_admin") {
-				return $this->is_admin;
-			} else if ($var == "client_ip") {
-				return $this->client_ip;
-			} else if (isset($this->record[$var])) {
-				return $this->record[$var];
+		public function __get($key) {
+			switch ($key) {
+				case "id": return $this->id;
+				case "logged_in": return $this->logged_in;
+				case "is_admin": return $this->is_admin;
+				case "client_ip": return $this->client_ip;
+				default:
+					if (isset($this->record[$key])) {
+						return $this->record[$key];
+					}
 			}
 
 			return null;
@@ -181,7 +180,7 @@
 		public function access_allowed($page) {
 			/* Always access
 			 */
-			$allowed = array("logout");
+			$allowed = array(LOGOUT_PAGE);
 			if ($this->is_admin || in_array($page, $allowed)) {
 				return true;
 			}
